#
# spec file for package python-cluster
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python36 1
Name:           python-cluster
Version:        1.4.1.post2
Release:        4.1
Summary:        Clustering library for python
License:        LGPL-2.0-or-later
URL:            https://github.com/exhuma/python-cluster
Source:         https://files.pythonhosted.org/packages/source/c/cluster/cluster-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib >= 1.2
Requires:       python-numpy >= 1.2
Requires:       python-scipy >= 0.12
BuildArch:      noarch
%python_subpackages

%description
The python-cluster package allows you to create several groups
(clusters) of objects from a list. It’s meant to be flexible and able
to cluster any object. To ensure this kind of flexibility, you need
not only to supply the list of objects, but also a function that
calculates the similarity between two of those objects. For simple
datatypes, like integers, this can be as simple as a subtraction, but
more complex calculations are possible. Right now, it is possible to
generate the clusters using a hierarchical clustering and the popular
K-Means algorithm. For the hierarchical algorithm there are different
“linkage” (single, complete, average and uclus) methods available.

%prep
%setup -q -n cluster-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/cluster
%{python_sitelib}/cluster-%{version}.dist-info

%changelog
* Fri May  9 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Sat Feb  3 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Mon May 24 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.4.1.post2
  * Update changelog.
  * Removed the Pipfile which was introduced in 1.4.1.post1.
    The file caused false positives on security checks.
    Additionally, having a Pipfile is mainly useful in
    applications, and not in libraries like this one.
- Update to 1.4.1.post1
  * Update changelog.
  * Switch doc-building to use pipenv & update Pipfile accordingly.
* Wed Jun 20 2018 tchvatal@suse.com
- Switch from wheel to normal distri packaging bsc#1094323
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 1.4.1
  * Added a "display" method to hierarchical clusters (by 1kastner).
  * issue in multiprocessing code.
  * Multiprocessing (by loisaidasam)
  * Python 3 support
  * Split up one big file into smaller more logical sub-modules
  * Fixed https://github.com/exhuma/python-cluster/issues/11
  * Documentation update.
- Implement single-spec version
- Switch to wheel-based package
* Thu Sep 26 2013 p.drouand@gmail.com
- Update to version 1.1.2
  + Changelog is not update and don't provide changes
- Replace python-distribute with python-setuptools BuildRequires
* Thu Jan  3 2013 toddrme2178@gmail.com
- Fix builds for SLES 11
* Thu Jan 12 2012 saschpe@suse.de
- Spec file cleanup:
  * Don't rm -rf %%buildroot
  * Fix license, it's LGPL-2.0+ (not BSD)
  * BuildRequire python-distribute instead of python-setuptools
  * Some macro cleanup
* Tue Jan 10 2012 jweberhofer@weberhofer.at
- initial release 1.1.1b3
